springheel_jacky — springheel_jacky 1.0.0 documentation

Skip to main content

# springheel_jacky

- springheel_jacky package
  - Submodules
  - springheel_jacky.categories module
  - springheel_jacky.chapters module
  - springheel_jacky.cli module
  - springheel_jacky.cbz module
  - springheel_jacky.images module
  - springheel_jacky.internet module
  - springheel_jacky.links module
  - springheel_jacky.search module
  - springheel_jacky.strips module
  - Module contents